/* repodlgs.c -- PLACEHOLDER */

#include <stdlib.h>

#include "repodlgs.h"
#include "repodlgs_common.h"

char *
get_report_title(char *report_name)
{
	/* PORTME */
	return NULL;
}

void
update_report_dialogs(void)
{
	/* PORTME */
}

void
science_dialog_update(void)
{
	/* PORTME */
}

void
popup_science_dialog(bool make_modal)
{
	/* PORTME */
}

void
economy_report_dialog_update(void)
{
	/* PORTME */
}

void
popup_economy_report_dialog(bool make_modal)
{
	/* PORTME */
}

void
activeunits_report_dialog_update(void)
{
	/* PORTME */
}

void
popup_activeunits_report_dialog(bool make_modal)
{
	/* PORTME */
}
